browser library

Classes

Browser
The main widget for the Browser navigation system.
BrowserConfig
BrowserRoute
Defines a single route in the application's navigation map.
DataParam<T>
DeepLinkParam
A special RouteParams class that holds URL query parameters.
ModalBase<T extends ModalBaseParams>
ModalBaseHeader
ModalBaseHeaderParameter
ModalBaseParams
ModalBaseSafeArea
ModalDraggableScrollableSheetParams
OverlayTraceRoute
PageObserverProvider
PageTraceRoute
PopupTraceRoute
RouteObserverProvider
RouteParams
An abstract base class for creating strongly-typed route arguments.
SafeAreaManager
Sheet
SheetBase<T extends ModalBaseParams>
SheetRouteParams
SwipeTraceRoute
Trace<T extends TraceRoute>
Represents a semantic navigation event.
TraceRoute
Defines the presentation style of a route.

Extensions

Typedefs

BrowserBuilder = Widget Function(BuildContext context, RouteObserver<ModalRoute<void>> routeObserver, Route generate(RouteSettings settings))
A function that builds the main widget of the application, providing access to the RouteObserver and the route generation function.
Check = bool Function<T extends RouteParams>()
GetArguments = T? Function<T extends RouteParams>()
OnNavigation = void Function(RouteSettings settings)
A callback that is triggered whenever a navigation event occurs.
ScrollableBuilder = Widget Function(BuildContext context, ScrollController? scrollController)