builderTrigger property
An optional function that is executed just before the page widget is built.
This is useful for triggering logic that depends on the route's context, such as dependency injection or analytics events.
Implementation
final Function(BuildContext context)? builderTrigger;