validateArguments property
An optional function to validate arguments before navigating to this route.
It receives two functions:
checkArgument: A function to check if an argument of a certain type exists and is valid (by calling itsvalidate()method).getArgument: A function to retrieve an argument of a certain type.
If this function returns false, the navigation is aborted, and the
defaultRoute from Browser is used instead.
Example:
validateArguments: (check, get) => check<ProfileArgs>(),
Implementation
final bool Function(Check checkArgument, GetArguments getArgument)?
validateArguments;