DeepLinkParam class final

A special RouteParams class that holds URL query parameters.

When a route is accessed via a URL with query parameters (e.g., /home?foo=bar), an instance of DeepLinkParam containing {'foo': 'bar'} is automatically added to the route's arguments.

Inheritance

Constructors

DeepLinkParam(Map<String, String> params)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
params Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate() bool
Validates the arguments. Returns true if the arguments are valid.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited