NavigatorX extension

on

Properties

Available on BuildContext, provided by the NavigatorX extension

no setter

Methods

canNavigate(String path) bool

Available on BuildContext, provided by the NavigatorX extension

cleanArguments({RouteSettings? settings}) → void

Available on BuildContext, provided by the NavigatorX extension

getArgument<T extends RouteParams?>() → T?

Available on BuildContext, provided by the NavigatorX extension

Reads an argument of type T from the current route's settings.
getArgumentAndClean<T extends RouteParams?>({RouteSettings? settings}) → T?

Available on BuildContext, provided by the NavigatorX extension

Reads an argument of type T and immediately removes it from the current route's settings.
launchAction(String action, {List<RouteParams>? args}) → void

Available on BuildContext, provided by the NavigatorX extension

Launches a navigation or URL action based on the given action string. Supports various navigation types via the navigateType query parameter.
openUrl(Uri uri) → void

Available on BuildContext, provided by the NavigatorX extension

pop<T extends RouteParams?>({T? args, RouteSettings? settings}) Future<void>

Available on BuildContext, provided by the NavigatorX extension

Pops the current route off the navigator.
popToFirst<T extends RouteParams?>({List<T> args = const [], RouteSettings? settings}) Future<void>

Available on BuildContext, provided by the NavigatorX extension

popToFirstAndPushNamed<T extends RouteParams?>(String path, {List<T> args = const []}) Future

Available on BuildContext, provided by the NavigatorX extension

popToFirstAndPushReplacementNamed<T extends RouteParams?>(String path, {List<T> args = const []}) Future

Available on BuildContext, provided by the NavigatorX extension

popToSelectOrFirstAndPushNamed<T extends RouteParams?>(String path, {List<T> args = const []}) Future

Available on BuildContext, provided by the NavigatorX extension

pushNamed<T extends RouteParams?>(String path, {List<T> args = const [], TraceRoute? traceRoute, RouteSettings? settings, NavigatorState? navigator}) Future

Available on BuildContext, provided by the NavigatorX extension

Navigates to a new route by its path.
pushReplacementNamed<T extends RouteParams?>(String path, {List<T> args = const [], TraceRoute? traceRoute, RouteSettings? settings, NavigatorState? navigator}) Future<void>

Available on BuildContext, provided by the NavigatorX extension

setPopArgument(RouteParams routeParams) → void

Available on BuildContext, provided by the NavigatorX extension

setPushArgument(RouteParams routeParams) → void

Available on BuildContext, provided by the NavigatorX extension