didPop property
Called when the current route has been popped off. !disappear
Implementation
final void Function(
BuildContext context,
)? didPop;
Called when the current route has been popped off. !disappear
final void Function(
BuildContext context,
)? didPop;