didPopNext property
Called when the top route has been popped off, and the current route shows up. !appears
Implementation
final void Function(
BuildContext context,
)? didPopNext;
Called when the top route has been popped off, and the current route shows up. !appears
final void Function(
BuildContext context,
)? didPopNext;