didPopNextWithArguments property

void Function(BuildContext context, DeepLinkParam? deepLinkParam)? didPopNextWithArguments
final

Called when the top route has been popped off, and the current route shows up with arguments. !appears

Implementation

final void Function(
  BuildContext context,
  DeepLinkParam? deepLinkParam,
)? didPopNextWithArguments;