didPushNext property
Called when a new route has been pushed, and the current route is no longer visible. !disappear
Implementation
final void Function(
BuildContext context,
)? didPushNext;
Called when a new route has been pushed, and the current route is no longer visible. !disappear
final void Function(
BuildContext context,
)? didPushNext;