DeferredBrowserRoute class
- Inheritance
-
- Object
- BrowserRoute
- DeferredBrowserRoute
Constructors
-
DeferredBrowserRoute({required String path, required Future loadPageLibrary(), required Widget pageBuilder(), Future<
void> initializeServiceLocator()?, Widget? onLoading, Widget? onError(Object? error)?, dynamic builderTrigger(BuildContext context)?, bool validateArguments(Check checkArgument, GetArguments getArgument)?, RouteTransition routeTransition = RouteTransition.slide_right})
Properties
- builderTrigger → dynamic Function(BuildContext context)?
-
An optional function that is executed just before the page widget is
built.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- page → Widget
-
The widget to be displayed when this route is active.
finalinherited
- path → String
-
The unique path for this route (e.g., '/profile').
finalinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
- routeTransition → RouteTransition
-
The default transition animation for this route.
This can be overridden by a TraceRoute during navigation.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - validateArguments → bool Function(Check checkArgument, GetArguments getArgument)?
-
An optional function to validate arguments before navigating to this route.
finalinherited
Methods
-
copyWith(
{String? path, Widget? page, RouteTransition? routeTransition, dynamic builderTrigger(BuildContext context)?, bool validateArguments(Check checkArgument, GetArguments getArgument)?}) → BrowserRoute -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCompletedBrowserRoute(
) → Future< BrowserRoute> - Converts this DeferredBrowserRoute into a BrowserRoute with its deferred content already loaded.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited