OverlayTraceRoute class

Inheritance

Constructors

OverlayTraceRoute({RouteTransition? routeTransition, bool opaque = false, bool maintainState = true, bool allowSnapshotting = false, ImageFilter? filter, TraversalEdgeBehavior? traversalEdgeBehavior, Color? barrierColor = const Color(0x8A000000), Duration reverseTransitionDuration = const Duration(milliseconds: 300), Duration transitionDuration = const Duration(milliseconds: 300), String barrierLabel = '', String semanticsLabel = ''})

Properties

allowSnapshotting bool
Whether this route can be snapshotted.
finalinherited
barrierColor Color?
Specifies the color of the modal barrier that darkens everything below the modal.
finalinherited
barrierDismissible bool
Whether you can dismiss this route by tapping the modal barrier.
finalinherited
barrierLabel String
The semantic label used for a dismissible barrier.
finalinherited
filter ImageFilter?
An image filter to apply to the routes below this one.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
maintainState bool
Whether the state of this route should be maintained when it is not visible.
finalinherited
opaque bool
Whether this route obscures the route beneath it.
finalinherited
reverseTransitionDuration Duration
The duration of the reverse transition animation.
finalinherited
routeTransition RouteTransition?
The transition animation to use when the route is pushed or popped. If null, the default transition from BrowserRoute is used.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel String
The semantic label for the route.
finalinherited
transitionDuration Duration
The duration of the transition animation.
finalinherited
traversalEdgeBehavior TraversalEdgeBehavior?
The behavior of the traversal policy for nodes in the subtree of this route.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited