enableDrag property

bool enableDrag
final

Specifies whether the bottom sheet can be dragged and dismissed by swiping downwards.

If true, the bottom sheet can be dragged and dismissed by swiping downwards.

Defaults is true.

Implementation

final bool enableDrag;