useSafeArea property

bool useSafeArea
final

If useSafeArea is true, a SafeArea is inserted.

If useSafeArea is false, the bottom sheet is aligned to the bottom of the page and isn't exposed to the top padding of the MediaQuery.

Default is false.

Implementation

final bool useSafeArea;