TraceRoute class sealed

Defines the presentation style of a route.

A TraceRoute object, or one of its subclasses (PageTraceRoute, PopupTraceRoute, SwipeTraceRoute), specifies how a route is presented on the screen. This includes its transition animation, modality (e.g., fullscreen, popup), barrier color, and other visual properties.

It can be provided directly to a Trace object to override the default presentation style defined in the BrowserRoute.

Implementers

Constructors

TraceRoute.page({RouteTransition? routeTransition, bool opaque = true, bool maintainState = true, bool allowSnapshotting = true, ImageFilter? filter, TraversalEdgeBehavior? traversalEdgeBehavior, Color? barrierColor = const Color(0x8A000000), Duration reverseTransitionDuration = const Duration(milliseconds: 300), Duration transitionDuration = const Duration(milliseconds: 300), bool barrierDismissible = false, String barrierLabel = '', String semanticsLabel = '', bool fullscreenDialog = false, bool popGestureEnabled = true})
Creates a PageTraceRoute for presenting a route as a standard, full-screen page.
factory
TraceRoute.popup({RouteTransition? routeTransition, bool opaque = false, bool maintainState = true, bool allowSnapshotting = false, ImageFilter? filter, TraversalEdgeBehavior? traversalEdgeBehavior, Color? barrierColor = const Color(0x8A000000), Duration reverseTransitionDuration = const Duration(milliseconds: 300), Duration transitionDuration = const Duration(milliseconds: 300), bool barrierDismissible = true, String barrierLabel = '', String semanticsLabel = ''})
Creates a PopupTraceRoute for presenting a route as a modal dialog or popup.
factory
TraceRoute.swipe({RouteTransition? routeTransition, bool opaque = false, bool maintainState = true, bool allowSnapshotting = false, ImageFilter? filter, TraversalEdgeBehavior? traversalEdgeBehavior, Color? barrierColor = const Color(0x8A000000), Duration reverseTransitionDuration = const Duration(milliseconds: 300), Duration transitionDuration = const Duration(milliseconds: 300), bool barrierDismissible = true, String barrierLabel = '', String semanticsLabel = '', bool useSafeArea = false, AxisDirection animationDirection = AxisDirection.up, bool enableDrag = true, double screenMaximumPercentage = 1, Offset? anchorPoint})
Creates a SwipeTraceRoute for presenting a route as a swipeable bottom sheet.
factory

Properties

allowSnapshotting bool
Whether this route can be snapshotted.
final
barrierColor Color?
Specifies the color of the modal barrier that darkens everything below the modal.
final
barrierDismissible bool
Whether you can dismiss this route by tapping the modal barrier.
final
barrierLabel String
The semantic label used for a dismissible barrier.
final
filter ImageFilter?
An image filter to apply to the routes below this one.
final
hashCode int
The hash code for this object.
no setterinherited
maintainState bool
Whether the state of this route should be maintained when it is not visible.
final
opaque bool
Whether this route obscures the route beneath it.
final
reverseTransitionDuration Duration
The duration of the reverse transition animation.
final
routeTransition RouteTransition?
The transition animation to use when the route is pushed or popped. If null, the default transition from BrowserRoute is used.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel String
The semantic label for the route.
final
transitionDuration Duration
The duration of the transition animation.
final
traversalEdgeBehavior TraversalEdgeBehavior?
The behavior of the traversal policy for nodes in the subtree of this route.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited