traversalEdgeBehavior property
The behavior of the traversal policy for nodes in the subtree of this route.
Implementation
final TraversalEdgeBehavior? traversalEdgeBehavior;
The behavior of the traversal policy for nodes in the subtree of this route.
final TraversalEdgeBehavior? traversalEdgeBehavior;