ContentBuilder typedef
Call a remove callback or use OverlayManager.of(context).removeActual can be the same if de actual is this
Implementation
typedef ContentBuilder = Widget Function(
FutureOr<void> Function() removableCallback,
);
Call a remove callback or use OverlayManager.of(context).removeActual can be the same if de actual is this
typedef ContentBuilder = Widget Function(
FutureOr<void> Function() removableCallback,
);