ModalBaseHeaderParameter class

Constructors

ModalBaseHeaderParameter({required Color background, required Color headerBackground, required Color dragBar, required Widget closeIcon, Color? closeIconColor, Widget? title})

Properties

background Color
final
closeIcon Widget
final
closeIconColor Color?
final
dragBar Color
final
hashCode int
The hash code for this object.
no setterinherited
headerBackground Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title Widget?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited