initialHeightChildSize property
The initial fractional value of the parent container's height to use when displaying the widget.
Rebuilding the sheet with a new initialChildSize will only move
the sheet to the new value if the sheet has not yet been dragged since it
was first built or since the last call to DraggableScrollableActuator.reset.
The default value is 0.4.
Implementation
final double initialHeightChildSize;