SafeAreaManager class final

Constructors

SafeAreaManager({required bool top, required bool right, required bool bottom, required bool left})
const
SafeAreaManager.all()
const
SafeAreaManager.fromLTRB(bool left, bool top, bool right, bool bottom)
const

Properties

bottom bool
final
hashCode int
The hash code for this object.
no setterinherited
left bool
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
safeArea({required Widget child}) SafeArea
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited