SheetBase<T extends ModalBaseParams> class abstract

Inheritance

Constructors

SheetBase({required ModalBase<T> modal, Key? key})
const

Properties

bodyPadding EdgeInsets
no setter
borderRadius BorderRadiusGeometry?
no setter
buttonBarPadding EdgeInsets
no setter
clipBehavior Clip
no setter
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

adjustSize({required double? extentTotal, required double? extentInside, required ScrollController? customScrollViewController, required DraggableScrollableController? draggableController}) → void
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scrollController({required BuildContext context, required Widget child}) PrimaryScrollController
sheetArea({required BuildContext context, required Widget child}) Widget
sheetCase({required BuildContext context, required ScrollableBuilder build, required DraggableScrollableController draggableController}) Widget
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited