enqueueBanner static method
Enqueues a banner to be displayed by the OverlayManager.
Banners are shown one by one in the order they are enqueued.
Implementation
static void enqueueBanner(
BuildContext context,
ContentBuilder content, {
double? topPadding,
}) =>
OverlayManager.enqueueBanner(
context,
content: content,
topPadding: topPadding,
);