SwipeUpLeftGestures class final
- Inheritance
-
- Object
- SwipeGestures
- SwipeUpLeftGestures
Constructors
- SwipeUpLeftGestures({required double obtainSize(), required AnimationController animationController, required bool canDragDone(), required VoidCallback onClosing, void dragStart(DragStartDetails)?, void dragEnd(DragEndDetails)?, double closePercentage = 0.5})
Properties
- animationController → AnimationController
-
finalinherited
- canDragDone → bool Function()
-
finalinherited
- closePercentage → double
-
finalinherited
- dragEnd → void Function(DragEndDetails)?
-
finalinherited
- dragStart → void Function(DragStartDetails)?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- obtainSize → double Function()
-
finalinherited
- onClosing → VoidCallback
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
handleDragEnd(
DragEndDetails details) → void -
inherited
-
handleDragStart(
DragStartDetails details) → void -
inherited
-
handleDragUpdate(
DragUpdateDetails details) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited