maintainState property
Whether the state of this route should be maintained when it is not visible.
If this is true, the route is kept in memory, and its state is preserved. If this is false, the route might be disposed of when it is not visible.
Implementation
final bool maintainState;