Banner class
- Inheritance
-
- Object
- OverlayModal
- Banner
Constructors
- Banner({required ContentBuilder content, required Duration? duration, required OverlayTraceRoute transition, required OverlayState overlayState, double topPadding = kAppbarHeight})
- Banner.fromContext({required BuildContext context, required ContentBuilder content, required OverlayTraceRoute transition, Duration? duration, double? topPadding})
-
factory
Properties
- completer ↔ Completer?
-
getter/setter pairinherited
- duration → Duration?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timer ↔ Timer?
-
getter/setter pairinherited
- topPadding → double
-
final
- transition → OverlayTraceRoute
-
finalinherited
Methods
-
insert(
) → Future -
create animation and overlayEntry an insert to overlayState
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
) → Future< void> -
remove overlayEntry
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited