Modal class

Inheritance

Constructors

Modal({required ContentBuilder content, required OverlayTraceRoute transition, required OverlayState overlayState, required Color backgroundColor, Duration? duration, Alignment alignment = Alignment.center, bool isDismissible = true, bool useSafeArea = false})

Properties

alignment Alignment
final
backgroundColor Color
final
completer Completer?
getter/setter pairinherited
duration Duration?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isDismissible bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timer Timer?
getter/setter pairinherited
transition OverlayTraceRoute
finalinherited
useSafeArea bool
final

Methods

insert() Future
create animation and overlayEntry an insert to overlayState
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove() Future<void>
remove overlayEntry
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited