OverlayModal class abstract
Constructors
- OverlayModal({required Duration? duration, required ContentBuilder content, required OverlayTraceRoute transition, required OverlayState overlayState})
Properties
- completer ↔ Completer?
-
getter/setter pair
- duration → Duration?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timer ↔ Timer?
-
getter/setter pair
- transition → OverlayTraceRoute
-
final
Methods
-
insert(
) → Future - create animation and overlayEntry an insert to overlayState
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
) → Future< void> - remove overlayEntry
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited