ModalDraggableScrollableSheetParams class base

Inheritance

Constructors

ModalDraggableScrollableSheetParams({double initialHeightChildSize = 0.4, double minHeightChildSize = 0.4, double maxHeightChildSize = 0.6, double withChildSize = 0.6, bool expand = true, bool snap = false, List<double>? snapSizes, Duration? snapAnimationDuration, bool shouldCloseOnMinExtent = true})
const
ModalDraggableScrollableSheetParams.large({double initialHeightChildSize = 0.45, double minHeightChildSize = 0.3, double maxHeightChildSize = 0.86, double withChildSize = 0.6, bool expand = true, bool snap = false, List<double>? snapSizes, Duration? snapAnimationDuration, bool shouldCloseOnMinExtent = true})
const
ModalDraggableScrollableSheetParams.medium({double initialHeightChildSize = 0.4, double minHeightChildSize = 0.4, double maxHeightChildSize = 0.6, double withChildSize = 0.6, bool expand = true, bool snap = false, List<double>? snapSizes, Duration? snapAnimationDuration, bool shouldCloseOnMinExtent = true})
const
ModalDraggableScrollableSheetParams.small({double initialHeightChildSize = 0.35, double minHeightChildSize = 0.35, double maxHeightChildSize = 0.75, double withChildSize = 0.6, bool expand = true, bool snap = false, List<double>? snapSizes, Duration? snapAnimationDuration, bool shouldCloseOnMinExtent = true})
const

Properties

expand bool
Whether the widget should expand to fill the available space in its parent or not.
final
hashCode int
The hash code for this object.
no setterinherited
initialHeightChildSize double
The initial fractional value of the parent container's height to use when displaying the widget.
final
maxHeightChildSize double
The maximum fractional value of the parent container's height to use when displaying the widget.
final
minHeightChildSize double
The minimum fractional value of the parent container's height to use when displaying the widget.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldCloseOnMinExtent bool
Whether the sheet, when dragged (or flung) to its minimum size, should cause its parent sheet to close.
final
snap bool
Whether the widget should snap between snapSizes when the user lifts their finger during a drag.
final
snapAnimationDuration Duration?
Defines a duration for the snap animations.
final
snapSizes List<double>?
A list of target sizes that the widget should snap to.
final
withChildSize double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited