ModalBase<T extends ModalBaseParams> class abstract

Constructors

ModalBase({required T params})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
params → T
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safeArea ModalBaseSafeArea
no setter

Methods

body({required BuildContext context, void changeDrawerSize(bool)?}) Widget
bottomBar(BuildContext context) Widget?
contextParameters({required BuildContext context}) ModalBaseHeaderParameter
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scrollPhysics(BuildContext context) ScrollPhysics?
topBar(ModalBaseHeaderParameter headerParameter, BorderRadiusGeometry? border) ModalBaseHeader
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited