SafeAreaManager class final
Constructors
- SafeAreaManager({required bool top, required bool right, required bool bottom, required bool left})
-
const
- SafeAreaManager.all()
-
const
- SafeAreaManager.fromLTRB(bool left, bool top, bool right, bool bottom)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
safeArea(
{required Widget child}) → SafeArea -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited